@@ -54,6 +54,7 @@ def upload_configs(  # noqa: D
     branch: Optional[str] = None,
     commit: Optional[str] = None,
     config_dir: Optional[str] = None,
+    is_current: Optional[bool] = None,
     api_url: Optional[str] = None,
 ) -> requests.Response:
 
@@ -89,7 +90,7 @@ def upload_configs(  # noqa: D
         commit_url = f"{url}/api/v1/model/{repo}/{branch}/{commit}/commit_model"
         logger.info(f"commit_url: {commit_url}")
         logger.info("Committing model")
-        r = requests.post(commit_url, headers=headers, verify=verify)
+        r = requests.post(commit_url, headers=headers, verify=verify, json=json.dumps({"is_current": is_current}))
         if r.status_code != 200:
             raise Exception(f"{ERROR_RESPONSE_PREFIX}{r.text}")
         logger.info("Successfully committed configs")
